@@ -23,7 +23,7 @@ draw_stones( "st-grate1", {1,35},{1,0},levelw-2)
 set_stone( "st-grate1", 1, 34)
 set_stone( "st-grate1", levelw-2,34)
 
-set_attrib( laser( 0,34, TRUE, EAST), "name", "laser")
+set_attrib( laser( 0,34, FALSE, EAST), "name", "laser")
 set_stone("st-switch", 0,30, {action="onoff", target="laser"})
 
 set_actor("ac-blackball", 10, 30, {player=0})
