@@ -39,3 +39,6 @@ oxyd_shuffle()
 
 set_actor("ac-blackball", 1.5, 6.5, {player=0})
 
+-- Call this only after setting the main actor, or the actor probably
+-- won't be inside the screen at when the game begins.
+display.SetFollowMode(display.FOLLOW_SCROLLING)
\ No newline at end of file
