@@ -5,7 +5,7 @@ create_world(levelw, levelh)
 stone="st-woven"
 
 draw_border( stone)
-fill_floor("fl-woven", 0,0, level_width,level_height)
+fill_floor("fl-stone", 0,0, level_width,level_height)
 draw_stones( stone, { 1,6}, {1,0}, 7)
 draw_stones( stone, {12,6}, {1,0}, 7)
 draw_stones( stone, { 5,1}, {0,1}, 4)
