@@ -1,24 +1,5 @@
-function LevelInfo()
-    return 
-    {
-        name="chaschds",
-        author="Daniel Heck",
-        difficulty="*"
-    }
-end
-
-function LevelInit()
-
-end
-
-function LevelDraw()
-
-end
-
-function LevelRestart()
-
-end
-
+-- Copyright (C) 2002 Daniel Heck
+enigma.ConserveLevel = TRUE
 levelw = 20
 levelh = 13
 
@@ -31,8 +12,6 @@ fill_floor("fl-hay", 0,0, level_width,level_height)
 set_stone("st-fart", levelw-1,0, {name="fart"})
 set_stone("st-timer", 0,0, {action="trigger", target="fart", interval=10})
 
-
-enigma.AddConstantForce(0,24)
 oxyd(3,3)
 oxyd(level_width-4,level_height-4)
 oxyd(level_width-4, 3)
